"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createCosmosConfig = createCosmosConfig;

var _cli = require("../shared/cli");

var _resolve = require("./resolve");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function createCosmosConfig(rootDir, cosmosConfigInput = {}) {
  return _objectSpread({}, cosmosConfigInput, {
    rootDir,
    exportPath: getExportPath(cosmosConfigInput, rootDir),
    staticPath: getStaticPath(cosmosConfigInput, rootDir),
    publicUrl: getPublicUrl(cosmosConfigInput),
    fixturesDir: getFixturesDir(cosmosConfigInput),
    fixtureFileSuffix: getFixtureFileSuffix(cosmosConfigInput),
    watchDirs: getWatchDirs(cosmosConfigInput, rootDir),
    userDepsFilePath: getUserDepsFilePath(cosmosConfigInput, rootDir),
    hostname: getHostname(cosmosConfigInput),
    port: getPort(cosmosConfigInput),
    globalImports: getGlobalImports(cosmosConfigInput, rootDir),
    ui: cosmosConfigInput.ui || {}
  });
}

function getExportPath(cosmosConfigInput, rootDir) {
  const {
    exportPath = 'cosmos-export'
  } = cosmosConfigInput;
  return (0, _resolve.resolvePath)(rootDir, exportPath);
}

function getStaticPath(cosmosConfigInput, rootDir) {
  const {
    staticPath = null
  } = cosmosConfigInput;
  return staticPath && (0, _resolve.resolvePath)(rootDir, staticPath);
}

function getPublicUrl({
  publicUrl = '/'
}) {
  return publicUrl;
}

function getFixturesDir({
  fixturesDir = '__fixtures__'
}) {
  return fixturesDir;
}

function getFixtureFileSuffix({
  fixtureFileSuffix = 'fixture'
}) {
  return fixtureFileSuffix;
}

function getWatchDirs(cosmosConfigInput, rootDir) {
  const {
    watchDirs = ['.']
  } = cosmosConfigInput;
  return watchDirs.map(watchDir => (0, _resolve.resolvePath)(rootDir, watchDir));
}

function getUserDepsFilePath(cosmosConfigInput, rootDir) {
  const {
    userDepsFilePath = 'cosmos.userdeps.js'
  } = cosmosConfigInput;
  return (0, _resolve.resolvePath)(rootDir, userDepsFilePath);
}

function getHostname({
  hostname = null
}) {
  return hostname;
}

function getPort(cosmosConfigInput) {
  const cliArgs = (0, _cli.getCliArgs)();

  if (typeof cliArgs.port === 'number') {
    return cliArgs.port;
  }

  const {
    port = 5000
  } = cosmosConfigInput;
  return port;
}

function getGlobalImports(cosmosConfigInput, rootDir) {
  const {
    globalImports = []
  } = cosmosConfigInput;
  return globalImports.map(globalImport => (0, _resolve.resolveModule)(rootDir, globalImport));
}