"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFixtures = getFixtures;

var _reactCosmosFixture = require("react-cosmos-fixture");

var _react = require("react-cosmos-shared2/react");

var _userDeps = require("./shared/userDeps");

async function getFixtures({
  cosmosConfig
}) {
  const {
    fixtureExportsByPath,
    decoratorsByPath
  } = await (0, _userDeps.getUserModules)(cosmosConfig);
  const fixtures = [];
  Object.keys(fixtureExportsByPath).forEach(fixturePath => {
    const fixtureExport = fixtureExportsByPath[fixturePath];

    if ((0, _react.isMultiFixture)(fixtureExport)) {
      // FIXME: Why does fixtureExport need to be cast as ReactFixtureMap when
      // the type predicate returned by isMultiFixture already ensures it?
      const multiFixtureExport = fixtureExport;
      Object.keys(fixtureExport).forEach(fixtureName => {
        const fixtureId = {
          path: fixturePath,
          name: fixtureName
        };
        fixtures.push({
          fixtureId,
          getElement: createFixtureElementGetter(multiFixtureExport[fixtureName], fixturePath, decoratorsByPath)
        });
      });
    } else {
      const fixtureId = {
        path: fixturePath,
        name: null
      };
      fixtures.push({
        fixtureId,
        getElement: createFixtureElementGetter(fixtureExport, fixturePath, decoratorsByPath)
      });
    }
  });
  return fixtures;
}

function createFixtureElementGetter(fixture, fixturePath, decoratorsByPath) {
  const decorators = (0, _react.getSortedDecoratorsForFixturePath)(fixturePath, decoratorsByPath);
  return () => (0, _reactCosmosFixture.getDecoratedFixtureElement)(fixture, decorators, {
    fixtureState: {},
    setFixtureState: () => {},
    onErrorReset: () => {}
  });
}