"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDevWebpackConfig = getDevWebpackConfig;

var _path = _interopRequireDefault(require("path"));

var _webpack = require("../cosmosConfig/webpack");

var _htmlPlugin = require("./htmlPlugin");

var _shared = require("./shared");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function getDevWebpackConfig(cosmosConfig, userWebpack) {
  const baseWebpackConfig = (0, _shared.getUserWebpackConfig)(cosmosConfig, userWebpack);
  return _objectSpread({}, baseWebpackConfig, {
    entry: getEntry(cosmosConfig),
    output: getOutput(cosmosConfig),
    module: _objectSpread({}, baseWebpackConfig.module, {
      rules: getRules(baseWebpackConfig)
    }),
    resolve: (0, _shared.resolveLocalReactDeps)(cosmosConfig, baseWebpackConfig),
    plugins: getPlugins(cosmosConfig, baseWebpackConfig, userWebpack)
  });
}

function getEntry(cosmosConfig) {
  const {
    hotReload
  } = (0, _webpack.createWebpackCosmosConfig)(cosmosConfig); // The React devtools hook needs to be imported before any other module that
  // might import React

  const devtoolsHook = (0, _shared.resolveDomRendererPath)('reactDevtoolsHook');
  const clientIndex = (0, _shared.resolveClientPath)('index');
  return hotReload ? [devtoolsHook, getHotMiddlewareEntry(), clientIndex] : [devtoolsHook, clientIndex];
}

function getOutput({
  publicUrl
}) {
  const filename = '[name].js';
  return {
    // Setting path to `/` in development (where files are saved in memory and
    // not on disk) is a weird required for old webpack versions
    path: '/',
    filename,
    publicPath: publicUrl,
    // Enable click-to-open source in react-error-overlay
    devtoolModuleFilenameTemplate: info => _path.default.resolve(info.absoluteResourcePath).replace(/\\/g, '/')
  };
}

function getRules(baseWebpackConfig) {
  const existingRules = baseWebpackConfig.module && baseWebpackConfig.module.rules || [];
  return [...existingRules, (0, _shared.getUserDepsLoaderRule)()];
}

function getPlugins(cosmosConfig, baseWebpackConfig, userWebpack) {
  const existingPlugins = baseWebpackConfig.plugins || [];
  const globalsPlugin = (0, _shared.getGlobalsPlugin)(cosmosConfig, userWebpack, true);
  const noEmitErrorsPlugin = new userWebpack.NoEmitOnErrorsPlugin();
  let plugins = [...existingPlugins, globalsPlugin, noEmitErrorsPlugin];
  const {
    hotReload
  } = (0, _webpack.createWebpackCosmosConfig)(cosmosConfig);

  if (hotReload && !(0, _shared.hasPlugin)(plugins, 'HotModuleReplacementPlugin')) {
    const hmrPlugin = new userWebpack.HotModuleReplacementPlugin();
    plugins = [...plugins, hmrPlugin];
  }

  return (0, _htmlPlugin.ensureHtmlWebackPlugin)(cosmosConfig, plugins);
}

function getHotMiddlewareEntry() {
  const clientPath = require.resolve('@skidding/webpack-hot-middleware/client');

  return `${clientPath}?reload=true&overlay=false`;
}